AlekSIS (School Information System) — App LDAP (General LDAP import/export)
==================================================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS`_ platform.

Features
--------

* Configurable sync strategies
* Management commands for ldap import
* Mass import of users and groups
* Sync LDAP users and groups on login

Licence
-------

::

  Copyright © 2020, 2021 Dominik George <dominik.george@teckids.org>
  Copyright © 2020 Tom Teichler <tom.teichler@teckids.org>

  Licenced under the EUPL, version 1.2 or later, by Teckids e.V. (Bonn, Germany).

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

.. _AlekSIS: https://aleksis.org/
.. _European Union Public Licence: https://eupl.eu/
